==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/change/vo/ChangesubpackagedetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.SubpackagedetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算变更子表
 * 
 * @author generator
 * 
 */
public class ChangesubpackagedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 单据编号
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String section; // 区段
    private java.lang.String subtitleCode; // 子目编码
    private java.lang.String subtitleName; // 子目名称
    private java.lang.String subtitleFeature; // 子目特征描述
    private java.lang.String measuringUnit; // 计量单位
    private java.math.BigDecimal quantities; // 工程量
    private java.math.BigDecimal artificialUnitPrice; // 人工费
    private java.math.BigDecimal materialsUnitPrice; // 材料费
    private java.math.BigDecimal mechanicalUnitPrice; // 机械费
    private java.math.BigDecimal enterpriseManageUnitPrice; // 企业管理费
    private java.math.BigDecimal profitsUnitPrice; // 利润
    private java.math.BigDecimal feesUnitPrice; // 规费
    private java.math.BigDecimal taxUnitPrice; // 税金
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    private java.math.BigDecimal artificialTotal; // 人工费
    private java.math.BigDecimal materialsTotal; // 材料费
    private java.math.BigDecimal mechanicalTotal; // 机械费
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    private java.math.BigDecimal profitsTotal; // 利润
    private java.math.BigDecimal feesTotal; // 规费
    private java.math.BigDecimal taxTotal; // 税金
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    private java.math.BigDecimal subpackageBudgetTotal; // 分包施工图预算量合计
    private java.math.BigDecimal subpackageQuantities; // 工程量
    private java.lang.String subpackageMeasuringUnit; // 计量单位
    private java.math.BigDecimal excludingTaxUnitPrice; // 除税单价
    private java.math.BigDecimal includingTaxUnitPrice; // 含税单价
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    private java.math.BigDecimal includingTaxTotal; // 含税合价
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private List<SubpackagedetailVO> children = new ArrayList<>();

    public List<SubpackagedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<SubpackagedetailVO> children) {
        this.children = children;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.math.BigDecimal quantities) {
        this.quantities = quantities;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialUnitPrice() {
        return artificialUnitPrice;
    }

    /**
     * 人工费
     */
    public void setArtificialUnitPrice(java.math.BigDecimal artificialUnitPrice) {
        this.artificialUnitPrice = artificialUnitPrice;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsUnitPrice() {
        return materialsUnitPrice;
    }

    /**
     * 材料费
     */
    public void setMaterialsUnitPrice(java.math.BigDecimal materialsUnitPrice) {
        this.materialsUnitPrice = materialsUnitPrice;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalUnitPrice() {
        return mechanicalUnitPrice;
    }

    /**
     * 机械费
     */
    public void setMechanicalUnitPrice(java.math.BigDecimal mechanicalUnitPrice) {
        this.mechanicalUnitPrice = mechanicalUnitPrice;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageUnitPrice() {
        return enterpriseManageUnitPrice;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageUnitPrice(java.math.BigDecimal enterpriseManageUnitPrice) {
        this.enterpriseManageUnitPrice = enterpriseManageUnitPrice;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsUnitPrice() {
        return profitsUnitPrice;
    }

    /**
     * 利润
     */
    public void setProfitsUnitPrice(java.math.BigDecimal profitsUnitPrice) {
        this.profitsUnitPrice = profitsUnitPrice;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesUnitPrice() {
        return feesUnitPrice;
    }

    /**
     * 规费
     */
    public void setFeesUnitPrice(java.math.BigDecimal feesUnitPrice) {
        this.feesUnitPrice = feesUnitPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 税金
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 分包施工图预算量合计
     */
    public java.math.BigDecimal getSubpackageBudgetTotal() {
        return subpackageBudgetTotal;
    }

    /**
     * 分包施工图预算量合计
     */
    public void setSubpackageBudgetTotal(java.math.BigDecimal subpackageBudgetTotal) {
        this.subpackageBudgetTotal = subpackageBudgetTotal;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getSubpackageQuantities() {
        return subpackageQuantities;
    }

    /**
     * 工程量
     */
    public void setSubpackageQuantities(java.math.BigDecimal subpackageQuantities) {
        this.subpackageQuantities = subpackageQuantities;
    }
    /**
     * 计量单位
     */
    public java.lang.String getSubpackageMeasuringUnit() {
        return subpackageMeasuringUnit;
    }

    /**
     * 计量单位
     */
    public void setSubpackageMeasuringUnit(java.lang.String subpackageMeasuringUnit) {
        this.subpackageMeasuringUnit = subpackageMeasuringUnit;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExcludingTaxUnitPrice() {
        return excludingTaxUnitPrice;
    }

    /**
     * 除税单价
     */
    public void setExcludingTaxUnitPrice(java.math.BigDecimal excludingTaxUnitPrice) {
        this.excludingTaxUnitPrice = excludingTaxUnitPrice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIncludingTaxUnitPrice() {
        return includingTaxUnitPrice;
    }

    /**
     * 含税单价
     */
    public void setIncludingTaxUnitPrice(java.math.BigDecimal includingTaxUnitPrice) {
        this.includingTaxUnitPrice = includingTaxUnitPrice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/change/vo/ChangesubpackagedetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.SubpackagedetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算变更子表
 * 
 * @author generator
 * 
 */
public class ChangesubpackagedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 单据编号
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String section; // 区段
    private java.lang.String subtitleCode; // 子目编码
    private java.lang.String subtitleName; // 子目名称
    private java.lang.String subtitleFeature; // 子目特征描述
    private java.lang.String measuringUnit; // 计量单位
    private java.math.BigDecimal quantities; // 工程量
    private java.math.BigDecimal artificialUnitPrice; // 人工费
    private java.math.BigDecimal materialsUnitPrice; // 材料费
    private java.math.BigDecimal mechanicalUnitPrice; // 机械费
    private java.math.BigDecimal enterpriseManageUnitPrice; // 企业管理费
    private java.math.BigDecimal profitsUnitPrice; // 利润
    private java.math.BigDecimal feesUnitPrice; // 规费
    private java.math.BigDecimal taxUnitPrice; // 税金
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    private java.math.BigDecimal artificialTotal; // 人工费
    private java.math.BigDecimal materialsTotal; // 材料费
    private java.math.BigDecimal mechanicalTotal; // 机械费
    private java.math.BigDecimal enterpriseManageTotal; // 企业管理费
    private java.math.BigDecimal profitsTotal; // 利润
    private java.math.BigDecimal feesTotal; // 规费
    private java.math.BigDecimal taxTotal; // 税金
    private java.math.BigDecimal comprehensiveTotal; // 合价（元）
    private java.math.BigDecimal subpackageBudgetTotal; // 分包施工图预算量合计
    private java.math.BigDecimal subpackageQuantities; // 工程量
    private java.lang.String subpackageMeasuringUnit; // 计量单位
    private java.math.BigDecimal excludingTaxUnitPrice; // 除税单价
    private java.math.BigDecimal includingTaxUnitPrice; // 含税单价
    private java.math.BigDecimal excludingTaxTotal; // 除税合价
    private java.math.BigDecimal includingTaxTotal; // 含税合价
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private List<ChangesubpackagedetailVO> children = new ArrayList<>();
    private java.lang.String errorMsg;
    private java.lang.String innercode;

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public List<ChangesubpackagedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangesubpackagedetailVO> children) {
        this.children = children;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubtitleCode() {
        return subtitleCode;
    }

    /**
     * 子目编码
     */
    public void setSubtitleCode(java.lang.String subtitleCode) {
        this.subtitleCode = subtitleCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubtitleName() {
        return subtitleName;
    }

    /**
     * 子目名称
     */
    public void setSubtitleName(java.lang.String subtitleName) {
        this.subtitleName = subtitleName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getSubtitleFeature() {
        return subtitleFeature;
    }

    /**
     * 子目特征描述
     */
    public void setSubtitleFeature(java.lang.String subtitleFeature) {
        this.subtitleFeature = subtitleFeature;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.math.BigDecimal quantities) {
        this.quantities = quantities;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialUnitPrice() {
        return artificialUnitPrice;
    }

    /**
     * 人工费
     */
    public void setArtificialUnitPrice(java.math.BigDecimal artificialUnitPrice) {
        this.artificialUnitPrice = artificialUnitPrice;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsUnitPrice() {
        return materialsUnitPrice;
    }

    /**
     * 材料费
     */
    public void setMaterialsUnitPrice(java.math.BigDecimal materialsUnitPrice) {
        this.materialsUnitPrice = materialsUnitPrice;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalUnitPrice() {
        return mechanicalUnitPrice;
    }

    /**
     * 机械费
     */
    public void setMechanicalUnitPrice(java.math.BigDecimal mechanicalUnitPrice) {
        this.mechanicalUnitPrice = mechanicalUnitPrice;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageUnitPrice() {
        return enterpriseManageUnitPrice;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageUnitPrice(java.math.BigDecimal enterpriseManageUnitPrice) {
        this.enterpriseManageUnitPrice = enterpriseManageUnitPrice;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsUnitPrice() {
        return profitsUnitPrice;
    }

    /**
     * 利润
     */
    public void setProfitsUnitPrice(java.math.BigDecimal profitsUnitPrice) {
        this.profitsUnitPrice = profitsUnitPrice;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesUnitPrice() {
        return feesUnitPrice;
    }

    /**
     * 规费
     */
    public void setFeesUnitPrice(java.math.BigDecimal feesUnitPrice) {
        this.feesUnitPrice = feesUnitPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    /**
     * 税金
     */
    public void setTaxUnitPrice(java.math.BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getArtificialTotal() {
        return artificialTotal;
    }

    /**
     * 人工费
     */
    public void setArtificialTotal(java.math.BigDecimal artificialTotal) {
        this.artificialTotal = artificialTotal;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialsTotal() {
        return materialsTotal;
    }

    /**
     * 材料费
     */
    public void setMaterialsTotal(java.math.BigDecimal materialsTotal) {
        this.materialsTotal = materialsTotal;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getEnterpriseManageTotal() {
        return enterpriseManageTotal;
    }

    /**
     * 企业管理费
     */
    public void setEnterpriseManageTotal(java.math.BigDecimal enterpriseManageTotal) {
        this.enterpriseManageTotal = enterpriseManageTotal;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 合价（元）
     */
    public java.math.BigDecimal getComprehensiveTotal() {
        return comprehensiveTotal;
    }

    /**
     * 合价（元）
     */
    public void setComprehensiveTotal(java.math.BigDecimal comprehensiveTotal) {
        this.comprehensiveTotal = comprehensiveTotal;
    }
    /**
     * 分包施工图预算量合计
     */
    public java.math.BigDecimal getSubpackageBudgetTotal() {
        return subpackageBudgetTotal;
    }

    /**
     * 分包施工图预算量合计
     */
    public void setSubpackageBudgetTotal(java.math.BigDecimal subpackageBudgetTotal) {
        this.subpackageBudgetTotal = subpackageBudgetTotal;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getSubpackageQuantities() {
        return subpackageQuantities;
    }

    /**
     * 工程量
     */
    public void setSubpackageQuantities(java.math.BigDecimal subpackageQuantities) {
        this.subpackageQuantities = subpackageQuantities;
    }
    /**
     * 计量单位
     */
    public java.lang.String getSubpackageMeasuringUnit() {
        return subpackageMeasuringUnit;
    }

    /**
     * 计量单位
     */
    public void setSubpackageMeasuringUnit(java.lang.String subpackageMeasuringUnit) {
        this.subpackageMeasuringUnit = subpackageMeasuringUnit;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExcludingTaxUnitPrice() {
        return excludingTaxUnitPrice;
    }

    /**
     * 除税单价
     */
    public void setExcludingTaxUnitPrice(java.math.BigDecimal excludingTaxUnitPrice) {
        this.excludingTaxUnitPrice = excludingTaxUnitPrice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getIncludingTaxUnitPrice() {
        return includingTaxUnitPrice;
    }

    /**
     * 含税单价
     */
    public void setIncludingTaxUnitPrice(java.math.BigDecimal includingTaxUnitPrice) {
        this.includingTaxUnitPrice = includingTaxUnitPrice;
    }
    /**
     * 除税合价
     */
    public java.math.BigDecimal getExcludingTaxTotal() {
        return excludingTaxTotal;
    }

    /**
     * 除税合价
     */
    public void setExcludingTaxTotal(java.math.BigDecimal excludingTaxTotal) {
        this.excludingTaxTotal = excludingTaxTotal;
    }
    /**
     * 含税合价
     */
    public java.math.BigDecimal getIncludingTaxTotal() {
        return includingTaxTotal;
    }

    /**
     * 含税合价
     */
    public void setIncludingTaxTotal(java.math.BigDecimal includingTaxTotal) {
        this.includingTaxTotal = includingTaxTotal;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
}
